@@ -116,16 +116,16 @@ class TrustedAuthTC(CubicWebTC):
                                                    login='admin',
                                                    signature=signature,
                                                    headers=headers)
-            self.assertEqual(401, req.status_out)
+            self.assertGreater(req.status_out, 400)
 
     def test_bad_http_auth_method(self):
         signature = self._build_signature('admin', '')
         result, req = self._test_header_format(method='AWS', login='admin', signature=signature)
-        self.assertEqual(401, req.status_out)
+        self.assertGreater(req.status_out, 400)
 
     def test_bad_signature(self):
         result, req = self._test_header_format(method='Cubicweb', login='admin', signature='YYY')
-        self.assertEqual(401, req.status_out)
+        self.assertGreater(req.status_out, 400)
 
     def test_deactivated_token(self):
         req = self.request()
@@ -137,7 +137,7 @@ class TrustedAuthTC(CubicWebTC):
                                                login='admin',
                                                signature=signature,
                                                headers=headers)
-        self.assertEqual(401, req.status_out)
+        self.assertGreater(req.status_out, 400)
 
     def test_bad_signature_url(self):
         def bad_build_string_to_sign(self, headers):
@@ -145,7 +145,7 @@ class TrustedAuthTC(CubicWebTC):
             return ''.join(get_headers(headers))
         self._build_string_to_sign = bad_build_string_to_sign
         result, req = self._test_header_format(method='Cubicweb', login='admin', signature='YYY')
-        self.assertEqual(401, req.status_out)
+        self.assertGreater(req.status_out, 400)
 
 
     def test_post_http_request_signature(self):
