@@ -129,7 +129,7 @@ class HttpRESTAuthRetriever(WebAuthInfoRetriever):
 # Tokens managment #############################################################
 
 
-from cubicweb.web import uicfg
+from cubicweb.web.views import uicfg
 
 _afs = uicfg.autoform_section
 _pvs = uicfg.primaryview_section
